pub fn walk(
input: &Handle,
result: &mut StructuredPrinter,
custom: &HashMap<String, Box<dyn TagHandlerFactory>>,
)Expand description
Recursively walk through all DOM tree and handle all elements according to HTML tag -> Markdown syntax mapping. Text content is trimmed to one whitespace according to HTML5 rules.
Arguments
input is DOM tree or its subtree
result is output holder with position and context tracking
custom is custom tag hadler producers for tags you want, can be empty